==> haskell-shelly-1.6.9-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.6.9
id: shelly-1.6.9-D3XrZPK8lSEHUwmQWIMwRS
key: shelly-1.6.9-D3XrZPK8lSEHUwmQWIMwRS
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
author: Greg Weber, Petr Rockai
exposed: True
indefinite: False
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find
abi: cfd959c562822262ba052b6ba9f30d52
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/shelly-1.6.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/shelly-1.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/shelly-1.6.9
hs-libraries: HSshelly-1.6.9-D3XrZPK8lSEHUwmQWIMwRS
depends:
    containers-0.5.10.2 time-1.8.0.2 directory-1.3.0.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH process-1.6.1.0
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    system-filepath-0.4.13.4-3TqvCgOYxDiENfvMWRc65v
    system-fileio-0.3.16.3-7auWLrqM4CK5UlNdO6310V
    monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
    lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8
    lifted-async-0.9.3-DeZKKnEItSp2yiA1dI3zP
    exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV
    enclosed-exceptions-1.0.2-CRL6WKonWv96zSD8qy2oBb
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj bytestring-0.10.8.2
    async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn transformers-0.5.2.0
    transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2 base-4.10.1.0
abi-depends: containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             system-filepath-0.4.13.4-3TqvCgOYxDiENfvMWRc65v=46f8a2f6c459dced3e9b89b04618141a
             system-fileio-0.3.16.3-7auWLrqM4CK5UlNdO6310V=93faff2d1018c6e2891dce96321c7472
             monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J=ce72e9c06e97f7bac790a30fd0148a82
             lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8=1acab8be8bf897c4c2e82cc63fed9725
             lifted-async-0.9.3-DeZKKnEItSp2yiA1dI3zP=1ce547cbcc8d6c807e063a55c9f33d1e
             exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV=488626f806840161fa9e32c70677324e
             enclosed-exceptions-1.0.2-CRL6WKonWv96zSD8qy2oBb=c0db015b764508b4631d8be791939fe6
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn=7d406f0044aa7af43d5b6fcf63e521db
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=0446e63134f05bfe811d0020407f145f
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.7.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.7.0
id: shelly-1.7.0-5G962cNDksa380bGaR8G8H
key: shelly-1.7.0-5G962cNDksa380bGaR8G8H
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
author: Greg Weber, Petr Rockai
exposed: True
indefinite: False
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find
abi: 08fee2ef7e78eb27b5d7d981065bb873
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/shelly-1.7.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/shelly-1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/shelly-1.7.0
hs-libraries: HSshelly-1.7.0-5G962cNDksa380bGaR8G8H
depends:
    containers-0.5.10.2 time-1.8.0.2 directory-1.3.0.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH process-1.6.1.0
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    system-filepath-0.4.13.4-3TqvCgOYxDiENfvMWRc65v
    system-fileio-0.3.16.3-7auWLrqM4CK5UlNdO6310V
    monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J
    lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8
    lifted-async-0.9.3.2-CCb7vEhkVAc1tcfbbiyqSA
    exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV
    enclosed-exceptions-1.0.2-CRL6WKonWv96zSD8qy2oBb
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj bytestring-0.10.8.2
    async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn transformers-0.5.2.0
    transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2 base-4.10.1.0
abi-depends: containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             system-filepath-0.4.13.4-3TqvCgOYxDiENfvMWRc65v=46f8a2f6c459dced3e9b89b04618141a
             system-fileio-0.3.16.3-7auWLrqM4CK5UlNdO6310V=93faff2d1018c6e2891dce96321c7472
             monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J=ce72e9c06e97f7bac790a30fd0148a82
             lifted-base-0.2.3.11-DwsH5fxK4NjGEU8txxSKm8=1acab8be8bf897c4c2e82cc63fed9725
             lifted-async-0.9.3.2-CCb7vEhkVAc1tcfbbiyqSA=d0106f334bc288126bcf57d9e7893f58
             exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV=488626f806840161fa9e32c70677324e
             enclosed-exceptions-1.0.2-CRL6WKonWv96zSD8qy2oBb=c0db015b764508b4631d8be791939fe6
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn=7d406f0044aa7af43d5b6fcf63e521db
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=0446e63134f05bfe811d0020407f145f
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
